@@ -119,7 +119,7 @@ def _inds_from_cols(stream, cols, types_, delimit, comment, skip_init_space):
 def _csv_attribs(stream, cols, types_, delimit, comment, skip_init_space):
     if not isinstance(delimit, type(b'')) or len(delimit) != 1:
         raise InvalidParamError('delimit', delimit, 'Must be a length-1 string')
-    if not isinstance(comment, type(b'')) or len(comment) != 1:
+    if comment is not None and (not isinstance(comment, type(b'')) or len(comment) != 1):
         raise InvalidParamError('comment', comment, 'Must be a length-1 string')
 
     cols, single, inds, uniques, copies, max_ind = _inds_from_cols(
@@ -187,8 +187,6 @@ def array_read(stream, cols, types_, missing_vals, delimit, comment, skip_init_s
 
     bufs = _make_bufs(c_types, max_field_len, max_elems)
 
-    # print (cols, single, inds, uniques, copies, max_ind, types_, c_types, c_missing_vals, cast_back)
-
     r = dagpype_c.ArrayColReader(
         stream, 
         delimit, comment, 1 if skip_init_space else 0, 
