@@ -781,7 +781,7 @@ def csv_split(
     cols = None, 
     types_ = None, 
     delimit = b',', 
-    comment = b'#', 
+    comment = None,
     skip_init_space = True):
 
     """
@@ -796,8 +796,8 @@ def csv_split(
             be cast to these types. Otherwise, if this is None (which is the default) the read values
             will be cast into floats.
         delimit -- Delimiting binary character (default b',').
-        comment -- Comment-starting binary character (default b'#"). Any character starting from this
-            one until the line end will be ignored.
+        comment -- Comment-starting binary character or ``None`` (default). 
+            Any character starting from this one until the line end will be ignored.
         skip_init_space -- Whether spaces starting a field will be ignored (default True).
 
     See Also:
