@@ -10,14 +10,15 @@ extern "C" PyObject *
 line_to_tuple(PyObject * self, PyObject * args)
 {
     char delimit;
+    bool has_comment;
     char comment;
     int skip_init_space;
-    PyObject * iterator;
+    PyObject * iterator, * comment_obj;
     if (!PyArg_ParseTuple(
             args, 
-            "Occi",
+            "OcOi",
             &iterator, 
-            &delimit, &comment, &skip_init_space)) {
+            &delimit, &comment_obj, &skip_init_space)) {
         return NULL;
     }
 
@@ -27,6 +28,8 @@ line_to_tuple(PyObject * self, PyObject * args)
         return NULL;
     }
 
+    _parse_comment(comment_obj, has_comment, comment);
+
     PyObject * const lineobj = PyIter_Next(iter);
     if (lineobj == NULL) {
         PyErr_SetString(PyExc_TypeError, "String expected in first line");
@@ -37,11 +40,17 @@ line_to_tuple(PyObject * self, PyObject * args)
     char * const line = pystring_as_string(lineobj, line_len);
 
     parsed_t parsed[max_num_cols];
-    const long num_parsed = _line_to_array(
-        NULL, NULL, 
-        0, 0,
-        delimit, comment, skip_init_space,
-        line, line_len, parsed);
+    const long num_parsed = has_comment?
+        _line_to_array(
+            NULL, NULL, 
+            0, 0,
+            delimit, comment, skip_init_space,
+            line, line_len, parsed) :
+        _line_to_array(
+            NULL, NULL, 
+            0, 0,
+            delimit, skip_init_space,
+            line, line_len, parsed);
     if (num_parsed <= 0) {
         Py_XDECREF(iter);
         Py_XDECREF(lineobj);
