@@ -74,14 +74,17 @@ parsed_to_double(const parsed_t & t, bool & err)
     err = false;
     char * e;
     const double d = strtod(t.first, &e);
+    
+    // Ugly hack
+    double ff = 1;
 
     if (e != t.second) {
         if (strncmp(t.first, "1.#IND", strlen("1.#IND")) == 0 || strncmp(t.first, "nan", strlen("nan")) == 0)
-            return NAN;
+            return log(-1.0);
         if (strncmp(t.first, "1.#INF", strlen("1.#INF")) == 0 || strncmp(t.first, "inf", strlen("inf")) == 0)
-            return INFINITY;                  
+            return 1.0 / (ff * ff - 2 * ff + 1);                  
         if (strncmp(t.first, "-1.#INF", strlen("-1.#INF")) == 0 || strncmp(t.first, "-inf", strlen("-inf")) == 0)
-            return -INFINITY;                  
+            return -1.0 / (ff * ff - 2 * ff + 1);                  
     
         err = true;
         PyErr_Format(PyExc_TypeError, ("Cannot format " + string(t.first, t.second) + " to float").c_str());
