@@ -13,6 +13,10 @@ import math
 sys.path.extend(['..', '../dagpype'])
 from dagpype import *
 import dagpype
+if sys.version_info < (3, 0):    
+    from _base2 import RandStateSaverBase as RandStateSaverBase
+else:     
+    from _base3 import RandStateSaverBase as RandStateSaverBase
 
 
 def _wind_rain_tags():
@@ -35,7 +39,7 @@ def _wind_rain_tags():
     return _act
 
 
-class _TestSeq00Basic(unittest.TestCase):
+class _TestSeq00Basic(unittest.TestCase, RandStateSaverBase):
     def test_00(self):
         with open('data/data.csv', 'rb') as f:
             source(f)
@@ -97,7 +101,7 @@ class _TestSeq00Basic(unittest.TestCase):
         self.assertEqual(f, 1)
 
 
-class _TestSeq01Streams(unittest.TestCase):
+class _TestSeq01Streams(unittest.TestCase, RandStateSaverBase):
     @classmethod
     def setUpClass(cls):
         if os.path.exists('tmp_data.csv'):
@@ -155,7 +159,7 @@ class _TestSeq01Streams(unittest.TestCase):
             self.assertEqual(data, data2)
 
 
-class _TestSeq02CSV(unittest.TestCase):
+class _TestSeq02CSV(unittest.TestCase, RandStateSaverBase):
     @classmethod
     def setUpClass(cls):
         if os.path.exists('tmp_data.csv'):
@@ -384,7 +388,7 @@ class _TestSeq02CSV(unittest.TestCase):
         self.assertTrue(math.isnan(l[2]))
 
 
-class _TestSeq03Control(unittest.TestCase):
+class _TestSeq03Control(unittest.TestCase, RandStateSaverBase):
     def test_01(self):
         self.assertEqual(source([1, 2, 3, 4]) | nth(1), 2)
         self.assertEqual(source([1, 2, 3, 4]) | nth(-1), 4)
@@ -579,7 +583,7 @@ class _TestSeq03Control(unittest.TestCase):
         self.assertEqual(source(['a', 'b', 'c', 'd']) | enumerate_(-1) | to_list(), [(-1, 'a'), (0, 'b'), (1, 'c'), (2, 'd')])
 
 
-class _TestSeq04Xml(unittest.TestCase):
+class _TestSeq04Xml(unittest.TestCase, RandStateSaverBase):
     def test_01(self):
         c = parse_xml(open('data/data.xml', 'rb')) | \
             _wind_rain_tags() | \
@@ -595,7 +599,7 @@ class _TestSeq04Xml(unittest.TestCase):
         self.assertAlmostEqual(c, 0.402186690128789)
 
 
-class _Test05Numeric(unittest.TestCase):
+class _Test05Numeric(unittest.TestCase, RandStateSaverBase):
     def test_00(self):
         n = source([1, 2, 3, 4]) | count()
         self.assertEqual(n, 4)
@@ -644,7 +648,7 @@ class _Test05Numeric(unittest.TestCase):
         self.assertLess(c, 1)
 
 
-class _Test06Fan(unittest.TestCase):
+class _Test06Fan(unittest.TestCase, RandStateSaverBase):
     def test_00(self):
         n0, n1 = source([1, 2, 3, 4]) | count() + count()
         self.assertEqual(n0, 4)
@@ -672,7 +676,7 @@ class _Test06Fan(unittest.TestCase):
         self.assertEqual(l[0], l[0])
 
 
-class _Test07Subgroup(unittest.TestCase):
+class _Test07Subgroup(unittest.TestCase, RandStateSaverBase):
     @classmethod
     def tearDownClass(cls):
         if os.path.exists('day_wind.csv'):
@@ -789,7 +793,7 @@ class _Test07Subgroup(unittest.TestCase):
         self.assertEqual(l, [(1, 2), (13, 1)])
 
 
-class _Test09FreezeThaw(unittest.TestCase):
+class _Test09FreezeThaw(unittest.TestCase, RandStateSaverBase):
     def test_00(self):
         s = freeze(sum_())
         for i in range(4):
@@ -822,14 +826,14 @@ class _Test09FreezeThaw(unittest.TestCase):
 
 
 # Tmp Ami - complete
-class _Test10Filenames(unittest.TestCase):
+class _Test10Filenames(unittest.TestCase, RandStateSaverBase):
     def test_00(self):
         l = os_walk('data') | count()
                     
         #filename_filt('*/data*.csv') | \
         
 
-class _Test11Numpy(unittest.TestCase):
+class _Test11Numpy(unittest.TestCase, RandStateSaverBase):
     @classmethod
     def setUpClass(cls):
         cls._num_vals = 100000
@@ -1041,7 +1045,7 @@ class _Test11Numpy(unittest.TestCase):
         self.assertEqual(l, r)                        
 
 
-class _Test12MovingAggs(unittest.TestCase):
+class _Test12MovingAggs(unittest.TestCase, RandStateSaverBase):
     def test_00(self):
         a = source([1., 2., 3., 4.]) | window_simple_ave(2) | to_list()
         self.assertEqual(a, [1., 1.5, 2.5, 3.5])
@@ -1082,7 +1086,7 @@ class _Test12MovingAggs(unittest.TestCase):
         self.assertEqual(a, [1., 3., 6., 10.])
 
 
-class _Test13Plotting(unittest.TestCase):
+class _Test13Plotting(unittest.TestCase, RandStateSaverBase):
     _a = numpy.arange(0, 2, 0.3)
 
     def test_01(self):    
@@ -1228,7 +1232,7 @@ class _Test13Plotting(unittest.TestCase):
             pass
             
 
-class _Test14NumpyCSV(unittest.TestCase):
+class _Test14NumpyCSV(unittest.TestCase, RandStateSaverBase):
     def test_00(self):
         for type_ in [int, bytes, float]:
             self.assertEqual(
@@ -1292,7 +1296,7 @@ class _Test14NumpyCSV(unittest.TestCase):
         os.remove('data/tmp_foo.csv')
 
 
-class _TestSeq15filterCSV(unittest.TestCase):
+class _TestSeq15filterCSV(unittest.TestCase, RandStateSaverBase):
     def test_00(self):
         l = source([b'foo,bar,wind', b'0,1,2', b'2,3.24,4']) | csv_split(cols = (b'foo',b'bar'), types_ = (float, float)) | to_list()
         self.assertEqual(l, [(0, 1), (2, 3.24)])
@@ -1306,7 +1310,7 @@ class _TestSeq15filterCSV(unittest.TestCase):
         self.assertEqual(l, [1, 3.24])
 
 
-class _TestSeq16Sed(unittest.TestCase):
+class _TestSeq16Sed(unittest.TestCase, RandStateSaverBase):
     def test_02(self):
         stream_lines('data/foo_sed_2.txt') | filt(lambda l: l + '\n', pre = lambda l: l.strip()) | to_stream('tmp2.txt')
         self.assertEqual(open('tmp2.txt').read(), open('data/bar_sed_2.txt').read())
